﻿using MediatR;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.ModelBinding;
using StatisticsService.Domain.Filters;
using StatisticsService.Domain.Queries;
using StatisticsService.Dto;
using ZData.Iam.Enforcer.Client;

namespace StatisticsService.Api.Controllers
{
    [Route("api/v1/clients")]
    [ApiController]
    [Authorize]
    public class ClientsController : ControllerBase
    {
        private readonly IEnforcer enforcer;
        private readonly IMediator mediator;

        public ClientsController(IEnforcer enforcer, IMediator mediator)
        {
            this.enforcer = enforcer;
            this.mediator = mediator;
        }

        /// <summary>
        /// Gets all client activity for active clients
        /// </summary>
        /// <remarks>Returns a list of daily counts and a period total of all unique client activity within requested date range.</remarks>
        [HttpGet]
        public async Task<ActionResult<ActiveResourceDto>> GetActiveClients([FromQuery] BaseFilter filter)
        {
            var response = await mediator.Send(new GetActiveClientsQuery(filter));

            if (response == null) return NotFound();

            return Ok(response);
        }

        /// <summary>
        /// Gets all client activity for client associated with a resource ID
        /// </summary>
        /// <remarks>Returns a list of daily counts and a period total of client activity associated with requested resource within requested date range</remarks>
        [HttpGet("{ResourceId}")]
        public async Task<ActionResult<ActiveResourceDto>> GetActiveClientsByResourceId([FromQuery] BaseFilterRID filter)
        {
            var response = await mediator.Send(new GetActiveClientsByResourceIdQuery(filter));

            if (response == null) return NotFound();

            return Ok(response);
        }

    }
}

