﻿using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using StatisticsService.Api.Clients;
using System;
using System.Net.Http.Headers;
using ZData.AccessServer.Client;
using ZData.Authentication.Extensions;
using ZData.Authentication.Providers;

namespace StatisticsService.Api.Extensions
{
    public static class HttpClientServiceCollectionExtensions
    {
        public static IServiceCollection AddHttpClients(this IServiceCollection services, IConfiguration configuration)
        {
            services.AddHttpClient("Security", c =>
            {
                c.BaseAddress = new Uri($"{configuration["Identity:BaseUrl"]}/connect/token");
                c.Timeout = TimeSpan.FromMinutes(1);
            });

            services.AddDelegatingAccessTokenProvider(configuration.GetSection("Identity"));
            services.AddNamedAccessTokenProvider(configuration.GetSection("Identity"), "identity");

            services.AddHttpClient<IZarManagementClient, ZarManagementClient>(c =>
            {
                c.BaseAddress = new Uri(configuration["Zar:BaseUrl"]);
                c.DefaultRequestHeaders.Accept.Clear();
                c.DefaultRequestHeaders.Accept.Add(new MediaTypeWithQualityHeaderValue("application/json"));
                c.Timeout = TimeSpan.FromMinutes(1);
            }).AddDelegatingAccessTokenDelegatingHandler();

            services.AddHttpClient<IZamManagementClient, ZamManagementClient>(c =>
            {
                c.BaseAddress = new Uri(configuration["Zam:BaseUrl"]);
                c.DefaultRequestHeaders.Accept.Clear();
                c.DefaultRequestHeaders.Accept.Add(new MediaTypeWithQualityHeaderValue("application/json"));
                c.Timeout = TimeSpan.FromMinutes(1);
            }).AddDelegatingAccessTokenDelegatingHandler();

            return services;
        }
    }
}
