﻿using StatisticsService.Api.Extensions.QueryExtensions;
using StatisticsService.Database;
using StatisticsService.Domain.Filters;
using StatisticsService.Dto;
using StatisticsService.Interfaces.Repository;
using ZData.AccessServer.Client;

namespace StatisticsService.Api.Repository
{
    public class AccountsRepository : BaseRepository, IAccountsRepository
    {
        /// <summary>
        /// Constructor
        /// </summary>
        public AccountsRepository(StatisticsServiceDbContext context) : base(context) { }
        public AccountsRepository(StatisticsServiceDbContext context, IZamManagementClient zamManagementClient) : base(context, zamManagementClient) { }

        public async Task<ActiveResourceDto> GetActiveAccountsByResourceId(BaseFilterRID filter)
        {
            var resourceIds = await GetResourceChildrensByResourceId(filter.ResourceId, filter.ResourceType);

            //Uncomment latter part of Where-clauses when account numbers are added to model.
            var daily = await Context.AggregatedEventsDay
                .Where(x => resourceIds.Any(resourceId => resourceId == x.TopicId) /* && x.AccountNumber != null */)
                .GetDailyActiveClientsFromQueryAsync(filter);

            var total = await Context.AggregatedEventsDay
                .Where(x => resourceIds.Any(resourceId => resourceId == x.TopicId) /* && x.AccountNumber != null */)
                .GetTotalActiveClientsFromQueryAsync(filter);

            return new ActiveResourceDto(daily, total);
        }

        public async Task<ActiveResourceDto> GetAllActiveAccounts(BaseFilter filter)
        {
            //Uncomment Where-clauses when account numbers are added to model.
            var daily = await Context.AggregatedEventsDay 
                //.Where(x => x.AccountNumber != null)
                .GetDailyActiveAccountsFromQueryAsync(filter);

            var total = await Context.AggregatedEventsDay
                //.Where(x => x.AccountNumber != null)
                .GetTotalActiveAccountsFromQueryAsync(filter);

            return new ActiveResourceDto(daily, total);
        }
    }
}
