﻿using StatisticsService.Api.Extensions.QueryExtensions;
using StatisticsService.Database;
using StatisticsService.Database.Models;
using StatisticsService.Domain.Filters;
using StatisticsService.Dto;
using StatisticsService.Interfaces.Repository;
using ZData.AccessServer.Client;

namespace StatisticsService.Api.Repository
{
    public class StatisticsRepository : BaseRepository, IStatisticsRepository
    {
        /// <summary>
        /// Constructor
        /// </summary>
        public StatisticsRepository(StatisticsServiceDbContext context) : base(context) { }
        public StatisticsRepository(StatisticsServiceDbContext context, IZamManagementClient zamManagementClient) : base(context, zamManagementClient) { }

        public async Task<IEnumerable<StatisticsDto>> GetStatistics(StatisticsFilter filter)
        {
            IQueryable<AggregatedEventBase> queryContext = Context.AggregatedEventsDay;

            if (filter.TimeType == "hour")
                queryContext = Context.AggregatedEventsHour;

            var query = queryContext.Where(x => x.EventType == filter.EventType);

            return await query.GetStatisticsFromQueryAsync(filter);
        }

        public async Task<IEnumerable<StatisticsDto>> GetStatisticsByResource(StatisticsFilterRID filter)
        {
            var resourceIds = await GetResourceChildrensByResourceId(filter.ResourceId, filter.ResourceType);

            IQueryable<AggregatedEventBase> queryContext = Context.AggregatedEventsDay;

            if (filter.TimeType == "hour")
                queryContext = Context.AggregatedEventsHour;

            var query = queryContext.Where(x => resourceIds.Any(resourceId => resourceId == x.TopicId) && x.EventType == filter.EventType);

            return await query.GetStatisticsFromQueryAsync(filter);
        }

        public async Task<IEnumerable<AggregatedStatisticsDto>> GetAggregatedStatistics(StatisticsFilter filter)
        {
            IQueryable<AggregatedEventBase> queryContext = Context.AggregatedEventsDay;

            if (filter.TimeType == "hour")
                queryContext = Context.AggregatedEventsHour;

            var query = queryContext.Where(x => x.EventType == filter.EventType);

            return await query.GetAggregatedStatisticsFromQueryAsync<AggregatedStatisticsDto>(filter);
        }

        public async Task<IEnumerable<AggregatedStatisticsDto>> GetAggregatedStatisticsByResource(StatisticsFilterRID filter)
        {
            var resourceIds = await GetResourceChildrensByResourceId(filter.ResourceId, filter.ResourceType);

            IQueryable<AggregatedEventBase> queryContext = Context.AggregatedEventsDay;

            if (filter.TimeType == "hour")
                queryContext = Context.AggregatedEventsHour;

            var query = queryContext.Where(x => resourceIds.Any(resourceId => resourceId == x.TopicId) && x.EventType == filter.EventType);

            return await query.GetAggregatedStatisticsFromQueryAsync<AggregatedStatisticsDto>(filter);
        }
    }
}