﻿using Microsoft.OpenApi.Models;
using System.Reflection;

namespace StatisticsService.Api.Swagger
{
    /// <summary>
    /// Class containing Swagger docs configurations.
    /// </summary>
    public static class SwaggerConfiguration
    {

        /// <summary>
        /// Method for injecting Swagger into a service collection
        /// </summary>
        /// <param name="services">an injectible service collection</param>
        /// <param name="configuration">a collection of ASP.NET application configuration values</param>
        public static void AddSwagger(this IServiceCollection services, IConfiguration configuration)
        {
            services.AddSwaggerGen(c =>
            {
                c.SwaggerDoc("v1", new OpenApiInfo
                { 
                    Title = "ZData Statistics Service API", 
                    Description = "An API for delivering aggregated statistics for various ZData services.",
                    Version = "v1",
                    Contact = new OpenApiContact
                    {
                        Name = "ZData AS",
                        Url = new Uri("https://www.zdata.no/kontakt-oss/")
                    },
                });

                c.AddSecurityDefinition("oauth2", new OpenApiSecurityScheme
                {
                    Type = SecuritySchemeType.OAuth2,
                    Flows = new OpenApiOAuthFlows
                    {
                        ClientCredentials = new OpenApiOAuthFlow
                        {
                            TokenUrl = new Uri($"{configuration["Identity:BaseUrl"]}/connect/token"),
                            Scopes = new Dictionary<string, string>() {
                                { configuration["Identity:Scope"], "Access to Statistics API" } }
                        },
                        Implicit = new OpenApiOAuthFlow
                        {
                            AuthorizationUrl = new Uri($"{configuration["Identity:BaseUrl"]}/connect/authorize"),
                            TokenUrl = new Uri($"{configuration["Identity:BaseUrl"]}/connect/token"),
                            Scopes = new Dictionary<string, string>() {
                                { configuration["Identity:Scope"], "Access to Statistics API" } }
                        },
                        Password = new OpenApiOAuthFlow
                        {
                            TokenUrl = new Uri($"{configuration["Identity:BaseUrl"]}/connect/token"),
                            Scopes = new Dictionary<string, string>() {
                                { configuration["Identity:Scope"], "Access to Statistics API" } }
                        }
                    }
                });

                c.AddSecurityRequirement(new OpenApiSecurityRequirement
                {
                    {
                        new OpenApiSecurityScheme
                        {
                            Reference = new OpenApiReference { Type = ReferenceType.SecurityScheme, Id = "oauth2" },
                            Type = SecuritySchemeType.OAuth2
                        },
                        new[] { configuration["Identity:Scope"] }
                    }
                });

                //Includes comments from API project.
                var xmlPath = Path.Combine(AppContext.BaseDirectory, $"{Assembly.GetExecutingAssembly().GetName().Name}.xml");
                c.IncludeXmlComments(xmlPath);

                //Includes entity documentation from Common project.
                var commonProjectEntitiesPath = Path.Combine(AppContext.BaseDirectory, "StatisticsService.Common.xml");
                c.IncludeXmlComments(commonProjectEntitiesPath);
            });
        }
    }
}
