﻿using MediatR;
using StatisticsService.Domain.Queries;
using StatisticsService.Dto;
using StatisticsService.Interfaces.Repository;
using System;
using System.Collections.Generic;
using System.Threading;
using System.Threading.Tasks;

namespace StatisticsService.Domain
{
    public class ClientsService : IRequestHandler<GetActiveClientsByResourceIdQuery, ActiveResourceDto>,
                                  IRequestHandler<GetActiveClientsQuery, ActiveResourceDto>
    {
        private readonly IClientsRepository clientsRepository;
        public ClientsService(IClientsRepository clientsRepository)
        {
            this.clientsRepository = clientsRepository;
        }

        public async Task<ActiveResourceDto> Handle(GetActiveClientsByResourceIdQuery query, CancellationToken cancellationToken)
        {
            return await clientsRepository.GetActiveClientsByResourceId(query.Filter);
        }

        public async Task<ActiveResourceDto> Handle(GetActiveClientsQuery query, CancellationToken cancellationToken)
        {
            return await clientsRepository.GetAllActiveClients(query.Filter);
        }
    }
}
