﻿using System;
using StatisticsService.Interfaces.Filters;

namespace StatisticsService.Domain.Filters
{
    public class BaseFilter : IBaseFilter
    {

        /// <summary>
        /// An ISO datestring defining the start of a requested period. Defaults to previous 7 days.
        /// </summary>
        public DateTime FromDate { get; set; }

        /// <summary>
        /// An ISO datestring defining the end of a requested period. Defaults to today.
        /// </summary>
        public DateTime ToDate { get; set; } = DateTime.Now;

        /// <summary>
        /// The amount of matching values to skip before returning. Starts at the end date.
		/// <br/><br/> Example: Take 2 returns a list of the last two matching elements.
        /// </summary>
        public int? Take { get; set; }

        /// <summary>
        /// The amount of matching values to skip before returning. Starts at the end date.
		/// <br/><br/> Example: Skip 2 returns a list with all elements preceeding the last two elements.
        /// </summary>
        public int Skip { get; set; } = 0;

        public BaseFilter()
        {
            FromDate = ToDate.AddDays(-6).Date;
        }
    }
}
 