﻿using System;
using Microsoft.AspNetCore.Mvc.ModelBinding;
using StatisticsService.Constants;
using StatisticsService.Interfaces.Filters;

namespace StatisticsService.Domain.Filters
{
    /// <summary>
    /// An encapsulation class for statistics request parameters.
    /// </summary>
    public class StatisticsFilter : BaseFilter, IStatisticsFilter
    {
        /// <summary>
        /// Private backing variable for EventType
        /// </summary>
        private string _eventType { get; set; }

        /// <summary>
        /// Defines which event type to request statistics for.
        /// </summary>
        /// <remarks>Automatically maps shorthand name to full event name</remarks>
        [BindRequired]
        public string EventType { get { return _eventType; } set { _eventType = Events.ConvertToFullEventName(value); }}

        /// <summary>
        /// Defines at what timescale to request statistics for. 
        /// <br/><br/> "hour" and "day" are valid values.
        /// </summary>
        public string TimeType { get; set; } = "day";

        public StatisticsFilter() : base()
        {
            ToDate = TimeType == "hour" ? ToDate.AddDays(1) : ToDate;
        }
    }
}
