﻿using MediatR;
using StatisticsService.Domain.Queries;
using StatisticsService.Dto;
using StatisticsService.Interfaces.Repository;
using System.Collections.Generic;
using System.Threading;
using System.Threading.Tasks;
using StatisticsService.Constants;

namespace StatisticsService.Domain
{
    public class ResourcesService : IRequestHandler<GetAllResourcesQuery, IEnumerable<ResourcesDto>>,
                                    IRequestHandler<GetAllResourceTypesQuery, IEnumerable<string>>

    {
        private readonly IResourcesRepository resourcesRepository;
        public ResourcesService(IResourcesRepository resourcesRepository)
        {
            this.resourcesRepository = resourcesRepository;
        }

        public async Task<IEnumerable<ResourcesDto>> Handle(GetAllResourcesQuery query, CancellationToken cancellationToken)
        {
            return await resourcesRepository.GetAllResourcesAsync(query.ResourceType);
        }

        public async Task<IEnumerable<string>> Handle(GetAllResourceTypesQuery query, CancellationToken cancellationToken)
        {
            return await Resources.AllResourceTypesAsync;
        }
    }
}