import '../styles/styles.scss'
import { Helmet } from 'react-helmet-async'
import { Routes, Route, Navigate } from 'react-router-dom'

import { AdminSecure } from './AdminSecure'
import { DashboardPage } from './pages/Dashboard/Loadable'
import { BankServicePage } from './pages/projects/BankService/Loadable'
import { BankServiceCompanyPage } from './pages/projects/BankService/Company/Loadable'
import { BankServicePartnerPage } from './pages/projects/BankService/Partner/Loadable'
import { SettlementPage } from './pages/projects/Settlement/Loadable'
import { UnauthorizedPage } from './pages/Unauthorized'
import { NotFoundPage } from './pages/NotFound/Loadable'
import { NavBar } from './components/NavBar'
import { SideBar } from './components/SideBar'

export const App = () => {
  return (
    <AdminSecure>
      <Helmet titleTemplate="%s - Statistics Service" defaultTitle="ZData - Statistics Service">
        <meta name="description" content="ZData - Statistics Service" />
      </Helmet>
      <div className="page">
        <div className="page-main">
          <NavBar />
          <SideBar />
          <Routes>
            <Route path={process.env.PUBLIC_URL + '/'} element={<Navigate to="/dashboard" />} />
            <Route path="/dashboard" element={<DashboardPage />} />
            <Route path="/authentication/callback" element={<Navigate to="/" />} />
            <Route path="/unauthorized" element={<UnauthorizedPage />} />
            <Route path="/projects/bankservice" element={<BankServicePage />} />
            <Route
              path="/projects/bankservice/company/:resourceId"
              element={<BankServiceCompanyPage />}
            />
            <Route
              path="/projects/bankservice/partner/:resourceId"
              element={<BankServicePartnerPage />}
            />
            {/* 
            <Route path="/projects/control" element={<ControlPage />} />
            */}
            <Route path="/projects/settlement" element={<SettlementPage />} />
            <Route path="*" element={<NotFoundPage />} />
          </Routes>
        </div>
      </div>
    </AdminSecure>
  )
}
