import { ReactNode, useEffect, useState } from 'react'
import { useLocation } from 'react-router-dom'

import { Breadcrumb } from './Breadcrumb'
import { capitalize } from 'utils'
import BreadcrumbChild from 'shared/interfaces/breadcrumbs.interface'

interface ContentProps {
  category: string
  subPage?: BreadcrumbChild
  currentPage: string
  children: ReactNode
  badgeText?: string
}

export const Content = ({ category, subPage, currentPage, children, badgeText }: ContentProps) => {
  const [badgeLabel, setBadgeLabel] = useState(badgeText)
  const location = useLocation()

  useEffect(() => {
    const validBadgePaths = ['partner', 'company']
    for (const path of validBadgePaths) {
      if (location.pathname.includes(path)) {
        setBadgeLabel(path)
        break
      }
    }
  }, [location.pathname])

  return (
    <div className="app-content">
      <div className="side-app">
        <div className="main-container container-fluid">
          <div className="page-header">
            <h1 className="page-title">
              {currentPage}
              {badgeLabel && (
                <span className="badge bg-primary text-white fs-13 badge-sm ms-3 align-middle mb-1">
                  {capitalize(badgeLabel)}
                </span>
              )}
            </h1>
            <Breadcrumb category={category} subPage={subPage} currentPage={currentPage} />
          </div>
          {children}
        </div>
      </div>
    </div>
  )
}
