import { useState } from 'react'
import DateRangePicker from 'rsuite/DateRangePicker'
import { DateRange } from 'rsuite/esm/DateRangePicker/types'
import dayjs from 'dayjs'
import 'rsuite/dist/rsuite.min.css'

import { useWindowDimensions } from 'utils/hooks/useWindowDimensions'

interface DatePickerProps {
  fromDate: Date
  toDate: Date
  onChange: (dates: DateRange | null) => void
}

export const DatePicker = ({ fromDate, toDate, onChange }: DatePickerProps) => {
  const [dates, setDates] = useState<DateRange | null>([fromDate, toDate])

  const { width } = useWindowDimensions()

  const onChangeDates = (dates: DateRange | null) => {
    setDates(dates)
    onChange(dates)
  }

  return (
    <DateRangePicker
      disabledDate={date => dayjs(date).isAfter(new Date())}
      onChange={onChangeDates}
      value={dates}
      character=" - "
      format="dd/MM/yyyy"
      isoWeek={true}
      size="lg"
      placement="auto"
      preventOverflow
      showOneCalendar={width < 600}
      style={{ width: width < 600 ? 180 : 200 }}
    />
  )
}
