import { useEffect } from 'react'
import { Link, useLocation } from 'react-router-dom'
import { MoreVertical, AlignLeft } from 'react-feather'

import { RightNav } from './RightNav'
import { ResourceSelectInput } from './ResourceSelectInput'
import { toggleSidebar } from 'utils'
import { useThemeStore } from 'store'
import Logo from 'assets/images/brand/logo.svg'
import WhiteLogo from 'assets/images/brand/logo-white.svg'

export const NavBar = () => {
  const isDarkMode = useThemeStore(state => state.isDarkMode)
  const location = useLocation()

  useEffect(() => {
    window.addEventListener('resize', () => {
      if (window.innerWidth <= 1024) {
        document.body.classList.remove('sidebar-show')
        document.body.classList.add('sidebar-gone')
        document.body.classList.remove('search-show')
      } else {
        document.body.classList.remove('sidebar-gone')
      }
    })
  }, [])

  return (
    <>
      <div className="app-header header sticky">
        <div className="container-fluid main-container">
          <div className="d-flex">
            <button
              type="button"
              aria-label="Hide Sidebar"
              className="app-sidebar__toggle navbar-toggler me-0"
              onClick={() => toggleSidebar(true)}
              data-bs-toggle="sidebar"
            >
              <AlignLeft className="w-80" />
            </button>
            <Link className="logo-horizontal" to="/">
              <img src={WhiteLogo} className="header-brand-img desktop-logo w-100p" alt="logo" />
              <img src={Logo} className="header-brand-img light-logo1 w-100p" alt="logo" />
            </Link>
            {location.pathname.includes('projects/bankservice') && (
              <div className="main-header-center ms-3 d-none d-lg-block">
                <ResourceSelectInput />
              </div>
            )}
            <div className="d-flex order-lg-2 ms-auto header-right-icons">
              <button
                className="navbar-toggler navresponsive-toggler d-lg-none ms-auto"
                type="button"
                data-bs-toggle="collapse"
                data-bs-target="#navbarSupportedContent-4"
                aria-controls="navbarSupportedContent-4"
                aria-expanded="false"
                aria-label="Toggle navigation"
              >
                <MoreVertical
                  className={`navbar-toggler-icon text-${isDarkMode ? 'white' : 'dark'} w-80`}
                />
              </button>
              <RightNav />
            </div>
          </div>
        </div>
      </div>
    </>
  )
}
