import { useEffect, useState } from 'react'
import { SingleValue } from 'react-select'
import Select from 'react-select-virtualized'

import ResourceOption from 'shared/interfaces/resource-option.interface'

interface Option {
  value: string
  label: string
}

interface CompareSelectProps {
  timeType: string
  value: ResourceOption | null
  onChange: (value: ResourceOption | null) => void
}

export const CompareSelect = ({ timeType, value, onChange }: CompareSelectProps) => {
  const [options, setOptions] = useState<Option[]>([])
  const [selectedValue, setSelectedValue] = useState<ResourceOption | null>(value)

  useEffect(() => {
    const defaultOptions = [
      { value: 'week', label: 'Previous week' },
      { value: 'month', label: 'Previous month' },
    ]
    if (timeType === 'hour') defaultOptions.unshift({ value: 'day', label: 'Previous day' })

    setOptions(defaultOptions)
  }, [timeType])

  const changeHandler = (option: SingleValue<ResourceOption>) => {
    setSelectedValue(option)
    onChange(option)
  }

  return (
    <Select
      className="react-select"
      classNamePrefix="resource-select-"
      options={options}
      placeholder="None"
      aria-label="Compare previous period menu"
      value={selectedValue}
      onChange={changeHandler}
    />
  )
}
