import { Modal, Button, CloseButton } from 'react-bootstrap'

import { CompareSelect } from '../CompareSelect'
import ResourceOption from 'shared/interfaces/resource-option.interface'

interface GraphSettingsModalProps {
  show: boolean
  setShow: (show: boolean) => void
  title: string
  timeType: string
  valueComparePeriod: ResourceOption | null
  onComparePeriodChange: (value: ResourceOption | null) => void
}

export const GraphSettingsModal = ({
  show,
  setShow,
  title,
  timeType,
  valueComparePeriod,
  onComparePeriodChange,
}: GraphSettingsModalProps) => {
  return (
    <Modal show={show} onHide={() => setShow(false)}>
      <Modal.Header>
        <h6 className="modal-title">{title} - Settings</h6>
        <CloseButton variant="white" />
      </Modal.Header>
      <Modal.Body>
        <div className="row">
          <div className="col-sm-6 d-flex align-items-center">Compare with previous period</div>
          <div className="col-sm-6">
            <CompareSelect
              timeType={timeType}
              value={valueComparePeriod}
              onChange={onComparePeriodChange}
            />
          </div>
        </div>
      </Modal.Body>
      <Modal.Footer>
        <Button variant="light" onClick={() => setShow(false)}>
          Close
        </Button>
      </Modal.Footer>
    </Modal>
  )
}
