import {
  Chart as ChartJS,
  CategoryScale,
  LinearScale,
  BarController,
  BarElement,
  LineController,
  LineElement,
  PointElement,
  Tooltip,
  ChartType,
  ChartOptions,
} from 'chart.js'
import { Chart } from 'react-chartjs-2'
import { ArrowUpCircle } from 'react-feather'
//import { ArrowDownCircle } from 'react-feather'

import { formatNumber } from 'utils'
import TypeChartDataset from 'shared/interfaces/chartjs/charts.interface'

ChartJS.register(
  CategoryScale,
  LinearScale,
  BarController,
  BarElement,
  LineController,
  LineElement,
  PointElement,
  Tooltip,
)

const CHART_OPTIONS: ChartOptions = {
  interaction: {
    mode: 'index',
    intersect: false,
  },
  maintainAspectRatio: false,
  responsive: true,
  plugins: {
    legend: {
      display: false,
    },
    title: {
      display: false,
    },
  },
  elements: {
    line: {
      tension: 0.5,
    },
  },
  scales: {
    x: {
      display: false,
      grid: {
        color: 'transparent',
      },
      ticks: {
        font: {
          size: 2,
        },
      },
    },
    y: {
      display: false,
      ticks: {
        display: false,
      },
    },
  },
}

const DATASETS_SETTINGS: TypeChartDataset = {
  secondary: {
    backgroundColor: 'transparent',
    borderColor: '#05c3fb',
    borderWidth: 2.5,
    categoryPercentage: 1.0,
    barPercentage: 1.0,
    barThickness: 5,
    pointBorderWidth: 3,
    pointRadius: 2,
    pointBorderColor: 'rgba(5, 195, 251, 0.5)',
    pointBackgroundColor: 'rgba(5, 195, 251, 0.6)',
  },
  green: {
    backgroundColor: 'transparent',
    borderColor: '#4ecc48',
    borderWidth: 2.5,
    categoryPercentage: 1.0,
    barPercentage: 1.0,
    barThickness: 5,
    pointBorderWidth: 3,
    pointRadius: 2,
    pointBorderColor: 'rgba(78, 204, 72, 0.5)',
    pointBackgroundColor: 'rgba(78, 204, 72, 0.6)',
  },
  pink: {
    backgroundColor: 'transparent',
    borderColor: '#f46ef4',
    borderWidth: 2.5,
    categoryPercentage: 1.0,
    barPercentage: 1.0,
    barThickness: 5,
    pointBorderWidth: 3,
    pointRadius: 2,
    pointBorderColor: 'rgba(244, 110, 244, 0.5)',
    pointBackgroundColor: 'rgba(244, 110, 244, 0.6)',
  },
  warning: {
    backgroundColor: 'transparent',
    borderColor: '#f7ba48',
    borderWidth: 2.5,
    categoryPercentage: 1.0,
    barPercentage: 1.0,
    barThickness: 5,
    pointBorderWidth: 3,
    pointRadius: 2,
    pointBorderColor: 'rgba(249, 180, 45, 0.5)',
    pointBackgroundColor: 'rgba(247, 186, 72, 0.6)',
  },
}

interface PlaceholderSmallWidgetProps {
  type: 'bar' | 'line'
  variant: 'secondary' | 'pink' | 'green' | 'warning'
  title: string
  data: number[]
  value: number
}

export const PlaceholderSmallWidget = ({
  type,
  variant,
  title,
  data,
  value,
}: PlaceholderSmallWidgetProps) => {
  //* TODO:
  //* Calculate labels last 7 days
  //* Graph = data for last 7 days (new clients etc)
  //* Calculate last week difference to current week (last 7 days)
  //* ArrowUpCircle - ArrowDownCircle icon logic based on previous week

  const labels = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']

  const datasets = {
    labels,
    datasets: [
      {
        data,
        ...DATASETS_SETTINGS[variant],
      },
    ],
  }

  return (
    <div className="col-lg-6 col-md-12 col-sm-12 col-xl-4">
      <div className="card overflow-hidden">
        <div className="card-body">
          <div className="d-flex">
            <div className="mt-2">
              <h6>{title}</h6>
              <h2 className="mb-0 number-font">{formatNumber(value)}</h2>
            </div>
            <div className="ms-auto">
              <Chart
                type={type as ChartType}
                options={CHART_OPTIONS}
                data={datasets}
                className="h-8 w-9 chart-dropshadow mt-2"
              />
            </div>
          </div>
          <span className="text-muted fs-14">
            <span className={`text-${variant}`}>
              <ArrowUpCircle className={`text-${variant}`} size="11" /> 5%
            </span>
            <span className="ms-1">Last week</span>
          </span>
        </div>
      </div>
    </div>
  )
}
