import { Helmet } from 'react-helmet-async'

import { Content } from 'app/components/Content'
import { Graph } from 'app/components/widgets/Graph'
import { Widget } from 'app/components/widgets/Widget'
import WidgetType from 'shared/enums/widget-type.enum'
import EventType from 'shared/enums/event-type.enum'
import WidgetParameters from 'shared/interfaces/widget/widget-parameters'
import StatisticsParameters from 'shared/interfaces/graph/statistics-parameters.interface'

export const BankServicePage = () => {
  const defaultWidgetParameters: WidgetParameters = {
    widgetType: WidgetType.clients,
  }

  const defaultGraphParameters: StatisticsParameters = {
    eventType: EventType.payments,
    timeType: '7-day',
  }

  return (
    <>
      <Helmet>
        <title>Bank Service</title>
      </Helmet>
      <Content category="Projects" currentPage="Bank Service">
        <div className="row">
          <div className="col-lg-12 col-md-12 col-sm-12 col-xl-12">
            <div className="row">
              <Widget
                type="line"
                variant="secondary"
                title="Active Clients"
                args={defaultWidgetParameters}
              />
              <Widget
                type="line"
                variant="pink"
                title="Active Accounts"
                args={{ ...defaultWidgetParameters, widgetType: WidgetType.accounts }}
              />
              <Widget
                type="line"
                variant="green"
                title="New Users"
                args={{ ...defaultWidgetParameters, widgetType: WidgetType.users }}
              />
            </div>
          </div>
        </div>
        <div className="row">
          <Graph
            type="line"
            variant="primary"
            title="Payments"
            args={{ ...defaultGraphParameters }}
          />
          <Graph
            type="line"
            variant="primary"
            title="Receivables"
            args={{ ...defaultGraphParameters, eventType: EventType.receivables }}
          />
        </div>
        <div className="row">
          <Graph
            type="line"
            variant="primary"
            title="Statements"
            args={{ ...defaultGraphParameters, eventType: EventType.statements }}
          />
        </div>
      </Content>
    </>
  )
}
